##  Synchronization Scope
  * Supported relation endpoints: Relations between any combination of mapped fact sheet types.
  * Synchronization direction: You can choose the source system to sync data from.
